Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 37 variants Moq(Error), Native(Error), Url(String), Utf8(Utf8Error), Connect(Arc<Error>), InvalidPointer, InvalidId, NotFound, SessionNotFound, OriginNotFound, AnnouncementNotFound, BroadcastNotFound, CatalogNotFound, MediaNotFound, TrackNotFound, GroupNotFound, FrameNotFound, UnknownFormat(String), InitFailed(Arc<Error>), BufferNotConsumed, TimestampOverflow(TimeOverflow), Level(String), InvalidCode, Panic, Offline, Unauthorized, Forbidden, Hang(Error), Mux(Error), NoIndex, NulError(NulError), Audio(Arc<Error>), Video(Arc<Error>), Json(String), JsonTrack(Arc<Error>), InvalidConfig(String), UnresolvableBroadcast(String),
}
Error types that can occur in the FFI layer.

Each error variant maps to a specific negative error code returned to C callers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Moq(Error)

Error from the underlying MoQ protocol layer.



Native(Error)

Error from the native helper layer (moq-tokio).



Url(String)

URL parsing error.



Utf8(Utf8Error)

UTF-8 string validation error.



Connect(Arc<Error>)

Connection establishment error.



InvalidPointer

Null or invalid pointer passed from C.



InvalidId

Invalid resource ID.



NotFound

Resource not found.



SessionNotFound

Session task not found.



OriginNotFound

Origin producer not found.



AnnouncementNotFound

Announcement not found.



BroadcastNotFound

Broadcast not found.



CatalogNotFound

Catalog not found.



MediaNotFound

Media decoder not found.



TrackNotFound

Track task not found.



GroupNotFound

Group producer not found.



FrameNotFound

Frame not found.



UnknownFormat(String)

Unknown media format specified.



InitFailed(Arc<Error>)

Initialization failed (e.g. logging setup).



BufferNotConsumed

Buffer was not fully consumed.



TimestampOverflow(TimeOverflow)

Timestamp value overflow.



Level(String)

Log level parsing error.



InvalidCode

Invalid error code conversion.



Panic

Panic occurred in Rust code.



Offline

Session is offline.



Unauthorized

Connection was rejected as unauthorized by the server.



Forbidden

Connection was forbidden by the server.



Hang(Error)

Error from the hang media layer.



Mux(Error)

Error from the moq-mux consumer layer.



NoIndex

Index out of bounds.



NulError(NulError)

Null byte found in C string.



Audio(Arc<Error>)

Error from the moq-audio codec layer.



Video(Arc<Error>)

Error from the moq-video codec layer.



Json(String)

Invalid JSON passed for a catalog section.



JsonTrack(Arc<Error>)

Error from the moq-json snapshot/stream layer.



InvalidConfig(String)

A client configuration value could not be parsed or initialized.



UnresolvableBroadcast(String)

A catalog rendition named another broadcast, but the broadcast it came from was not resolved through an origin, so there is nothing to resolve the reference against.