moq_publish_json_stream_append

Function moq_publish_json_stream_append 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn moq_publish_json_stream_append( stream: u32, value: *const c_char, value_len: usize, ) -> i32
Append one record to a JSON stream track. value is a UTF-8 JSON document.

Returns a zero on success, or a negative code on failure.

Safety

  • The caller must ensure value is a valid pointer to value_len bytes.