#[unsafe(no_mangle)]pub unsafe extern "C" fn moq_client_get_backoff_initial(
client: u32,
out: *mut u64,
) -> i32Expand description
Read the first reconnect delay, in milliseconds. See moq_client_set_backoff_initial.
Returns zero on success, or a negative code if the handle is unknown or out is NULL.
Safety
- The caller must ensure that
outpoints to a writableuint64_t.